# Generated by Django 3.0.13 on 2022-06-25 07:13

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('categories', '0008_mptt'),
    ]

    operations = [
        migrations.AddField(
            model_name='category',
            name='order',
            field=models.PositiveIntegerField(default=0),
        ),
    ]
