# Generated by Django 3.0.10 on 2020-11-22 09:01

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('categories', '0005_logo'),
    ]

    operations = [
        migrations.AddField(
            model_name='category',
            name='icon',
            field=models.CharField(blank=True, max_length=255, verbose_name='Icon'),
        ),
    ]
