# Generated by Django 3.0.10 on 2020-11-22 08:59

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('categories', '0002_title'),
    ]

    operations = [
        migrations.AddField(
            model_name='category',
            name='description',
            field=models.TextField(blank=True, max_length=4096, verbose_name='Description'),
        ),
    ]
