# Generated by Django 3.0.10 on 2020-11-22 09:00

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('categories', '0004_code'),
    ]

    operations = [
        migrations.AddField(
            model_name='category',
            name='logo',
            field=models.ImageField(blank=True, max_length=255, null=True, upload_to='categories', verbose_name='Logo'),
        ),
    ]
